package SPVM::Byte;

1;

=head1 NAME

SPVM::Byte - Byte Utility

=head1 CLASS METHODS

=head2 new

B<sub new : Byte ($class : class, $value : byte)>

Construct L<Byte|SPVM::Byte> object.

=head1 METHODS

B<sub get_value : byte ($self : self)>

Get byte value.
