package SPVM::Double;

1;

=head1 NAME

SPVM::Double - Double Utility

=head1 CLASS METHODS

=head2 new

B<sub new : double ($class : class, $value : double)>

Construct L<double|SPVM::double> object.

=head1 METHODS

B<sub get_value : double ($self : self)>

Get double value.

