package SPVM::Int;

1;

=head1 NAME

SPVM::Int - Int Utility

=head1 CLASS METHODS

=head2 new

B<sub new : Int ($class : class, $value : int)>

Construct L<Int|SPVM::Int> object.

=head1 METHODS

B<sub get_value : int ($self : self)>

Get int value.


