package SPVM::Float;

1;

=head1 NAME

SPVM::Float - Float Utility

=head1 CLASS METHODS

=head2 new

B<sub new : Float ($class : class, $value : float)>

Construct L<Float|SPVM::Float> object.

=head1 METHODS

B<sub get_value : float ($self : self)>

Get float value.
