package SPVM::Number::Util;

1;

=head1 NAME

SPVM::Number::Util - Number utilities

=head1 CLASS METHODS

=head2 BYTE_MIN_VALUE

B<sub BYTE_MIN_VALUE : byte ($class : class)>

A constant holding the minimum value a byte can have, C<-128>.

=head2 BYTE_MAX_VALUE

B<BYTE_MAX_VALUE : byte ($class : class)>

A constant holding the maximum value a byte can have, C<127>.

=head2 BYTE_BYTES

B<sub BYTE_BYTES : int ($class : class)>

The number of bytes used to represent a byte value in two's complement binary form, C<1>.

=head2 BYTE_SIZE

B<sub BYTE_SIZE : int ($class : class)>

The number of bits used to represent a byte value in two's complement binary form, C<8>.

=head2 SHORT_MIN_VALUE

B<sub SHORT_MIN_VALUE : short ($class : class)>

A constant holding the minimum value a short can have, C<-32768>.

=head2 SHORT_MAX_VALUE

B<sub SHORT_MAX_VALUE : short ($class : class)>

A constant holding the maximum value a short can have, C<32767>.

=head2 SHORT_BYTES

B<sub SHORT_BYTES : int ($class : class)>

The number of shorts used to represent a short value in two's complement binary form, C<2>.

=head2 SHORT_SIZE

B<sub SHORT_SIZE : int ($class : class)>

The number of bits used to represent a short value in two's complement binary form, C<16>.

=head2 INT_MIN_VALUE

B<sub INT_MIN_VALUE : int ($class : class)>

A constant holding the minimum value a int can have, C<-2147483648>.

=head2 INT_MAX_VALUE

B<sub INT_MAX_VALUE : int ($class : class)>

A constant holding the maximum value a int can have, C<2147483647>.

=head2 INT_BYTES

B<sub INT_BYTES : int ($class : class)>

The number of ints used to represent a int value in two's complement binary form, C<4>.

=head2 INT_SIZE

B<sub INT_SIZE : int ($class : class)>

The number of bits used to represent a int value in two's complement binary form, C<32>.

=head2 LONG_MIN_VALUE

B<sub LONG_MIN_VALUE : long ($class : class)>

A constant holding the minimum value a long can have, C<-9223372036854775808>.

=head2 LONG_MAX_VALUE

B<sub LONG_MAX_VALUE : long ($class : class)>

A constant holding the maximum value a long can have, C<9223372036854775807>.

=head2 LONG_BYTES

B<sub LONG_BYTES : int ($class : class)>

The number of longs used to represent a long value in two's complement binary form, C<8>.

=head2 LONG_SIZE

B<sub LONG_SIZE : int ($class : class)>

The number of bits used to represent a long value in two's complement binary form, C<64>.

=head2 FLOAT_MIN_VALUE

B<sub FLOAT_MIN_VALUE : float ($class : class)>

A constant holding the minimum value a float can have, C<-128>.

=head2 FLOAT_MAX_VALUE

B<sub FLOAT_MAX_VALUE : float ($class : class)>

A constant holding the maximum value a float can have, C<127>.

=head2 FLOAT_SIZE

B<sub FLOAT_SIZE : int ($class : class)>

The number of bits used to represent a float value in two's complement binary form.

=head2 FLOAT_BYTES

B<sub FLOAT_BYTES : int ($class : class)>

The number of floats used to represent a float value in two's complement binary form.

=head2 DOUBLE_MIN_VALUE

B<sub DOUBLE_MIN_VALUE : double ($class : class)>

A constant holding the minimum value a double can have, C<-128>.

=head2 DOUBLE_MAX_VALUE

B<sub DOUBLE_MAX_VALUE : double ($class : class)>

A constant holding the maximum value a double can have, C<127>.

=head2 DOUBLE_SIZE

B<sub DOUBLE_SIZE : int ($class : class)>

The number of bits used to represent a double value in two's complement binary form.

=head2 DOUBLE_BYTES

B<sub DOUBLE_BYTES : int ($class : class)>

The number of doubles used to represent a double value in two's complement binary form.

