package SPVM::Short;

1;

=head1 NAME

SPVM::Short - Short Utility

=head1 CLASS METHODS

=head2 new

B<sub new : Short ($class : class, $value : short)>

Construct L<Short|SPVM::Short> object.

=head1 METHODS

B<sub get_value : short ($self : self)>

Get short value.
