/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     MY = 258,
     HAS = 259,
     SUB = 260,
     PACKAGE = 261,
     IF = 262,
     ELSIF = 263,
     ELSE = 264,
     RETURN = 265,
     FOR = 266,
     WHILE = 267,
     USE = 268,
     NEW = 269,
     OUR = 270,
     SELF = 271,
     CLASS = 272,
     LAST = 273,
     NEXT = 274,
     NAME = 275,
     CONSTANT = 276,
     ENUM = 277,
     DESCRIPTOR = 278,
     CORETYPE = 279,
     UNDEF = 280,
     CROAK = 281,
     VAR_NAME = 282,
     INTERFACE = 283,
     REF = 284,
     ISA = 285,
     SWITCH = 286,
     CASE = 287,
     DEFAULT = 288,
     VOID = 289,
     EVAL = 290,
     BYTE = 291,
     SHORT = 292,
     INT = 293,
     LONG = 294,
     FLOAT = 295,
     DOUBLE = 296,
     STRING = 297,
     WEAKEN = 298,
     SPECIAL_ASSIGN = 299,
     ASSIGN = 300,
     OR = 301,
     AND = 302,
     BIT_XOR = 303,
     BIT_OR = 304,
     BIT_AND = 305,
     REL = 306,
     SHIFT = 307,
     REMAINDER = 308,
     DIVIDE = 309,
     MULTIPLY = 310,
     UMINUS = 311,
     ARRAY_LENGTH = 312,
     NOT = 313,
     DEC = 314,
     INC = 315,
     ARROW = 316
   };
#endif
/* Tokens.  */
#define MY 258
#define HAS 259
#define SUB 260
#define PACKAGE 261
#define IF 262
#define ELSIF 263
#define ELSE 264
#define RETURN 265
#define FOR 266
#define WHILE 267
#define USE 268
#define NEW 269
#define OUR 270
#define SELF 271
#define CLASS 272
#define LAST 273
#define NEXT 274
#define NAME 275
#define CONSTANT 276
#define ENUM 277
#define DESCRIPTOR 278
#define CORETYPE 279
#define UNDEF 280
#define CROAK 281
#define VAR_NAME 282
#define INTERFACE 283
#define REF 284
#define ISA 285
#define SWITCH 286
#define CASE 287
#define DEFAULT 288
#define VOID 289
#define EVAL 290
#define BYTE 291
#define SHORT 292
#define INT 293
#define LONG 294
#define FLOAT 295
#define DOUBLE 296
#define STRING 297
#define WEAKEN 298
#define SPECIAL_ASSIGN 299
#define ASSIGN 300
#define OR 301
#define AND 302
#define BIT_XOR 303
#define BIT_OR 304
#define BIT_AND 305
#define REL 306
#define SHIFT 307
#define REMAINDER 308
#define DIVIDE 309
#define MULTIPLY 310
#define UMINUS 311
#define ARRAY_LENGTH 312
#define NOT 313
#define DEC 314
#define INC 315
#define ARROW 316




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



